# Variable
#
# A Variable represents a state variable of the simulation system.
# Each Variable has a finite quantity and can be incremented, decremented, or
# assigned over the course of the simulation. A Variable can also have a boolean
# value.
#
# e.g. For a supermarket checkout simulation, a finite Variable
#      would be the number of cashiers.
#
# Instance Variables:
# - @value            integer value of variable
#                     e.g. @value = 5
# - @name             name of the variable
#                     e.g. @name = 'Queue'
# - @description      description of the variable
#                     e.g. @description = 'Number of customers in line.'

class Shrewd::Variable
  include Comparable
  attr_accessor :name, :description, :value

  # Initialize the variable
  #
  # Input:
  # - name              name of the variable
  # - description       description of the variable (optional)
  # - default           default value for variable (optional)
  def initialize(name, description = '', default = 0)
    @value = default
    @name = name
    @description = description
  end

  # Increment the value of the variable
  #
  # Input:
  # - amount          the amount to increment the variable (optional)
  def increment(amount = 1)
    @value += amount
  end

  # Decrement the value of the variable
  #
  # Input:
  # - amount          the amount to decrement the variable (optional)
  def decrement(amount = 1)
    @value -= amount
  end

  # Compare variable value to number
  #
  # Input:
  # - val        the value to be compared with
  def <=>(val)
    @value <=> val
  end
end
